Learn R Programming

seedCCA (version 3.1)

print.seedCCA: basic function for printing class "seedCCA"

Description

The function controls to print class "seedCCA". The function prints the estimated coefficents, if they exist. For subclass "finalCCA", canonical correlations are additionally reported. For subsclass "selectu", increments, suggested number of projections and the values of type and eps are reported.

Usage

# S3 method for seedCCA
print(x,…)

Arguments

x

The name of an object of class "seedCCA"

arguments passed to the print.method

Examples

Run this code
# NOT RUN {
########  data(cookie) ########
data(cookie)
myseq<-seq(141,651,by=2)
X<-as.matrix(cookie[-c(23,61),myseq])
Y<-as.matrix(cookie[-c(23,61),701:704])

fit.seed2 <- seedCCA(X,Y)
fit.seed2
print(fit.seed2)
# }

Run the code above in your browser using DataLab